Resting state and noise acquisition — BCI-Framework documentation

# Resting state and noise acquisition

Implemented through extensions systems in the RestingNoiseAcquisition module.

This experiment perforn the same task implemented in 1: Resting with open eyes, Resting with close eye, Eye blinking, Eyeball movement up/down, Eyeball movement left/right, Head movement left/right and Jaw clenching. The time acquisition time for each task can be configured independently. The subject can explicitly. The subject can explicitly decide when to continue with the next task with a keyboard event.

## Configuration options

All tasks have the same configuration option, the acquisition time, from 0 (disabled task) to 5 minutes, 1 minute by default.

### References

1

  Hohyun Cho, Minkyu Ahn, Sangtae Ahn, Moonyoung Kwon, and Sung Chan Jun. Eeg datasets for motor imagery brain–computer interface. GigaScience, 6(7):gix034, 2017.